summaryrefslogtreecommitdiffstats
path: root/tools/win
diff options
context:
space:
mode:
authorscottmg@chromium.org <scottmg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-12 17:06:52 +0000
committerscottmg@chromium.org <scottmg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-12 17:06:52 +0000
commit112569c9a6034d0d20def025fe1ecb96718470f4 (patch)
tree90e8a55874a98bd09e69bf2f338b11bde016762e /tools/win
parentb0a042ffd0b83ece0cc90e128d9f946c2d115d4c (diff)
downloadchromium_src-112569c9a6034d0d20def025fe1ecb96718470f4.zip
chromium_src-112569c9a6034d0d20def025fe1ecb96718470f4.tar.gz
chromium_src-112569c9a6034d0d20def025fe1ecb96718470f4.tar.bz2
fix tools/win/toolchain/toolchain.py x64 setup
Previously we pulled the update, then the old version, then the update's binaries. This was to get the new compiler binaries, but the old headers. But, in x64 it turns out we actually need the new headers. So, now, pull the base version, then update in expected order, and patch the headers to work. This matches the recently updated instructions on https://sites.google.com/a/chromium.org/dev/developers/how-tos/build-instructions-windows now, in creating a stub ammintrin.h. Initial commit in http://src.chromium.org/viewvc/chrome?view=rev&revision=175004 BUG=169531 R=cpu@chromium.org Review URL: https://chromiumcodereview.appspot.com/11870002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@176554 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'tools/win')
-rw-r--r--tools/win/toolchain/toolchain.py30
1 files changed, 11 insertions, 19 deletions
diff --git a/tools/win/toolchain/toolchain.py b/tools/win/toolchain/toolchain.py
index 1f0c7e2..a733de6 100644
--- a/tools/win/toolchain/toolchain.py
+++ b/tools/win/toolchain/toolchain.py
@@ -314,22 +314,10 @@ def CopyToFinalLocation(extracted, target_dir):
]
PullFrom(from_headers, extracted.headers, target_dir)
- # The compiler update to get the SP1 x86 compiler is a bit of a mess. See
- # http://goo.gl/n1DeO. The summary is that update for the standalone
- # compiler binary installs a broken set of headers. So, we need to pull the
- # new binaries from the update, but keep the older set of headers.
-
- from_vcupdate_x86 = [
- (r'Program Files\Microsoft Visual Studio 10.0', '.'),
- (r'Win\System', r'VC\bin'),
- ]
- PullFrom(from_vcupdate_x86, extracted.update_x86, target_dir)
-
- from_vcupdate_x64 = [
- (r'Program Files(64)\Microsoft Visual Studio 10.0', '.'),
- (r'Win\System64', r'VC\bin\amd64'),
- ]
- PullFrom(from_vcupdate_x64, extracted.update_x64, target_dir)
+ # The compiler update to get the SP1 compiler is a bit of a mess. See
+ # http://goo.gl/n1DeO. The summary is that update for the standalone compiler
+ # binary installs a broken set of headers. So, add an empty ammintrin.h since
+ # we don't actually need the contents of it (for Chromium).
from_sdk7_x86 = [
(r'Program Files\Microsoft Visual Studio 10.0', '.'),
@@ -343,17 +331,21 @@ def CopyToFinalLocation(extracted, target_dir):
]
PullFrom(from_sdk7_x64, extracted.vc_x64, target_dir)
- # Now, re-get just the binaries from the update.
from_vcupdate_x86 = [
- (r'Program Files\Microsoft Visual Studio 10.0\VC\bin', r'VC\bin'),
+ (r'Program Files\Microsoft Visual Studio 10.0', '.'),
+ (r'Win\System', r'VC\bin'),
]
PullFrom(from_vcupdate_x86, extracted.update_x86, target_dir)
from_vcupdate_x64 = [
- (r'Program Files(64)\Microsoft Visual Studio 10.0\VC\bin', r'VC\bin'),
+ (r'Program Files(64)\Microsoft Visual Studio 10.0', '.'),
+ (r'Win\System64', r'VC\bin\amd64'),
]
PullFrom(from_vcupdate_x64, extracted.update_x64, target_dir)
+ sys.stdout.write('Stubbing ammintrin.h...\n')
+ open(os.path.join(target_dir, r'VC\include\ammintrin.h'), 'w').close()
+
from_dxsdk = [
(r'DXSDK\Include', r'DXSDK\Include'),
(r'DXSDK\Lib', r'DXSDK\Lib'),